@@ -203,6 +203,10 @@ void Fl_set_font(int o, int n) {
     Fl::set_font(o, n);
 }
 
+void Fl_set_font2(int o, const char *n) {
+    Fl::set_font(o, n);
+}
+
 void Fl_set_font_size(int sz) {
     Fl::lock();
     FL_NORMAL_SIZE = sz;
@@ -602,9 +606,11 @@ const char *Fl_load_font(const char *path) {
         return nullptr;
     }
     int length = 0;
+
     const char *info =
         stbtt_GetFontNameString(&font, &length, STBTT_PLATFORM_ID_MAC,
-                                STBTT_UNICODE_EID_UNICODE_1_0, STBTT_MAC_EID_ROMAN, 1);
+                                STBTT_MAC_EID_ROMAN, STBTT_MAC_LANG_ENGLISH, 4);
+
     char *str = (char *)malloc(length + 1);
     snprintf(str, length + 1, "%s", info);
     auto ret = i_load_private_font(path);
